@@ -5,7 +5,7 @@ use XML::Simple qw{};
 
 BEGIN {
     use vars qw($VERSION);
-    $VERSION     = '0.02';
+    $VERSION     = '0.03';
 }
 
 =head1 NAME
@@ -16,17 +16,32 @@ Geo::GoogleEarth::Document - Creates a GoogleEarth KML Document
 
   use Geo::GoogleEarth::Document;
   my $document    = Geo::GoogleEarth::Document->new();  #is a special Folder...
-  my $folder      = $document->Folder();      #Geo::GoogleEarth::Document::Folder object
-  my $placemark   = $document->Placemark();   #Geo::GoogleEarth::Document::Placemark object
-  my $networklink = $document->NetworkLink(); #Geo::GoogleEarth::Document::NetworkLink object
+  my $folder      = $document->Folder();                #Geo::GoogleEarth::Document::Folder object
+  my $placemark   = $document->Placemark();             #Geo::GoogleEarth::Document::Placemark object
+  my $networklink = $document->NetworkLink();           #Geo::GoogleEarth::Document::NetworkLink object
   print $document->render();
 
 =head1 DESCRIPTION
 
+Geo::GoogleEarth::Document is a Perl object oriented interface that allows for the creation of XML documents that can be used with Google Earth.
+
+Geo::GoogleEarth::Document is a L<Geo::GoogleEarth::Document::Folder> with a render method.
+
 =head1 USAGE
 
+This is all of the code you need to generate a complete Google Earth document.
+
+  use Geo::GoogleEarth::Document;
+  my $document=Geo::GoogleEarth::Document->new();
+  $document->Placemark(address=>q{1600 Pennsylvania Ave NW, Washington, DC});
+  print $document->render;
+
 =head2 render
 
+Returns an XML document with an XML declaration and a root name of "Document"
+
+  print $document->render;
+
 =cut
 
 sub render {
@@ -40,13 +55,12 @@ sub render {
 
 =head1 SUPPORT
 
+Try geo-perl email list.
+
 =head1 AUTHOR
 
-    Michael R. Davis
+    Michael R. Davis (mrdvt92)
     CPAN ID: MRDVT
-    STOP, LLC
-    domain=>stopllc,tld=>com,account=>mdavis
-    http://www.stopllc.com/
 
 =head1 COPYRIGHT
 
